==> apache-kie-10.0.0-incubating-sources.zip: incubator-kie-tools/packages/extended-services-vscode-extension/src/configurations/ConfigurationWatcher.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import * as vscode from "vscode";
import * as configuration from "./Configuration";

export class ConfigurationWatcher {
  private configurationChangedHandler: (() => void) | null;
  private configurationChangeListener: vscode.Disposable | undefined;

  constructor() {
    this.configurationChangeListener = vscode.workspace.onDidChangeConfiguration(this.handleConfigurationChange, this);
  }

  private handleConfigurationChange(configurationChange: vscode.ConfigurationChangeEvent) {
    const enableAutoRunChanged = configurationChange.affectsConfiguration(configuration.enableAutoRunID);
    const connectionHeartbeatIntervalinSecsChanged = configurationChange.affectsConfiguration(
      configuration.connectionHeartbeatIntervalinSecsID
    );
    const extendedServicesURLChanged = configurationChange.affectsConfiguration(configuration.extendedServicesURLID);

    if (enableAutoRunChanged || connectionHeartbeatIntervalinSecsChanged || extendedServicesURLChanged) {
      this.fireConfigurationChangedEvent();
    }
  }

  private fireConfigurationChangedEvent() {
    this.configurationChangedHandler?.();
  }

  public subscribeSettingsChanged(handler: () => void) {
    this.configurationChangedHandler = handler;
  }

  public unsubscribeSettingsChanged() {
    this.configurationChangedHandler = null;
  }

  public dispose(): void {
    this.unsubscribeSettingsChanged();
    this.configurationChangeListener?.dispose();
  }
}

==> apache-kie-10.1.0-incubating-sources.zip: incubator-kie-tools/packages/extended-services-vscode-extension/src/configurations/ConfigurationWatcher.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import * as vscode from "vscode";
import * as configuration from "./Configuration";

export class ConfigurationWatcher {
  private configurationChangedHandler: (() => void) | null;
  private configurationChangeListener: vscode.Disposable | undefined;

  constructor() {
    this.configurationChangeListener = vscode.workspace.onDidChangeConfiguration(this.handleConfigurationChange, this);
  }

  private handleConfigurationChange(configurationChange: vscode.ConfigurationChangeEvent) {
    const enableAutoRunChanged = configurationChange.affectsConfiguration(configuration.enableAutoRunID);
    const connectionHeartbeatIntervalInSecsChanged = configurationChange.affectsConfiguration(
      configuration.connectionHeartbeatIntervalInSecsID
    );
    const extendedServicesURLChanged = configurationChange.affectsConfiguration(configuration.extendedServicesURLID);

    if (enableAutoRunChanged || connectionHeartbeatIntervalInSecsChanged || extendedServicesURLChanged) {
      this.fireConfigurationChangedEvent();
    }
  }

  private fireConfigurationChangedEvent() {
    this.configurationChangedHandler?.();
  }

  public subscribeSettingsChanged(handler: () => void) {
    this.configurationChangedHandler = handler;
  }

  public unsubscribeSettingsChanged() {
    this.configurationChangedHandler = null;
  }

  public dispose(): void {
    this.unsubscribeSettingsChanged();
    this.configurationChangeListener?.dispose();
  }
}
